@@ -24,6 +24,9 @@ class Client:
             f"{self.scheme}://{self.bucket}.cos.{self.region}.myqcloud.com", key
         )
 
+    def get(self, key, **kwargs):
+        return self.request("GET", key, **kwargs)
+
     def request(self, method, key, **kwargs):
         url = self.get_object_url(key)
         return requests.request(
